Domain

Struct Domain 

pub struct Domain { /* private fields */ }
Holds information about a particular domain

This is created by List::parse_domain.

Implementations

Source

impl Domain

pub fn has_valid_syntax(domain: &str) -> bool

Check if a domain has valid syntax

pub fn full(&self) -> &str

Get the full domain

pub fn root(&self) -> Option<&str>

Gets the root domain portion if any

pub fn suffix(&self) -> Option<&str>

Gets the suffix if any

pub fn is_private(&self) -> bool

Whether the domain has a private suffix

pub fn is_icann(&self) -> bool

Whether the domain has an ICANN suffix

pub fn has_known_suffix(&self) -> bool

Whether this domain’s suffix is in the list

If it is, this is definately a valid domain. If it’s not chances are very high that this isn’t a valid domain name, however, it might simply be because the suffix is new and it hasn’t been added to the list yet.

If you want to validate a domain name, use this as a quick check but fall back to a DNS lookup if it returns false.